==> pubnub-3.7.14-0.jar: cljsjs/pubnub/common/pubnub.ext.js <==
// generated
// using http://www.dotnetwise.com/Code/Externs/index.html
var PUBNUB = {
    "LEAVE": function () {},
    "LEAVE_GROUP": function () {},
    "set_resumed": function () {},
    "get_cipher_key": function () {},
    "set_cipher_key": function () {},
    "raw_encrypt": function () {},
    "raw_decrypt": function () {},
    "get_heartbeat": function () {},
    "set_heartbeat": function () {},
    "get_heartbeat_interval": function () {},
    "set_heartbeat_interval": function () {},
    "get_version": function () {},
    "getGcmMessageObject": function () {},
    "getApnsMessageObject": function () {},
    "newPnMessage": function () {},
    "_add_param": function () {},
    "channel_group": function () {},
    "channel_group_list_groups": function () {},
    "channel_group_list_channels": function () {},
    "channel_group_remove_channel": function () {},
    "channel_group_remove_group": function () {},
    "channel_group_add_channel": function () {},
    "channel_group_cloak": function () {},
    "channel_group_list_namespaces": function () {},
    "channel_group_remove_namespace": function () {},
    "history": function () {},
    "replay": function () {},
    "auth": function () {},
    "time": function () {},
    "publish": function () {},
    "unsubscribe": function () {},
    "subscribe": function () {},
    "here_now": function () {},
    "where_now": function () {},
    "state": function () {},
    "grant": function () {},
    "mobile_gw_provision": function () {},
    "audit": function () {},
    "revoke": function () {},
    "set_uuid": function () {},
    "get_uuid": function () {},
    "isArray": function () {},
    "get_subscibed_channels": function () {},
    "presence_heartbeat": function () {},
    "stop_timers": function () {},
    "shutdown": function () {},
    "xdr": function () {},
    "ready": function () {},
    "db": {
        "get": function () {},
        "set": function () {}
    },
    "uuid": function () {},
    "map": function () {},
    "each": function () {},
    "each-channel": function () {},
    "grep": function () {},
    "offline": function () {},
    "supplant": function () {},
    "now": function () {},
    "unique": function () {},
    "updater": function () {},
    "css": function () {},
    "$": function () {},
    "create": function () {},
    "bind": function () {},
    "head": function () {},
    "search": function () {},
    "attr": function () {},
    "events": {
        "list": function () {},
        "unbind": function () {},
        "bind": function () {},
        "fire": function () {}
    },
    "init": function () {},
    "secure": function () {},
    "crypto_obj": {
        "encrypt": function () {},
        "decrypt": function () {}
    },
    "ws": function () {}
}

==> pubnub-3.8.0-0.jar: cljsjs/pubnub/common/pubnub.ext.js <==
// generated
// using http://www.dotnetwise.com/Code/Externs/index.html
var PUBNUB = {
    "LEAVE": function () {},
    "LEAVE_GROUP": function () {},
    "set_resumed": function () {},
    "get_cipher_key": function () {},
    "set_cipher_key": function () {},
    "raw_encrypt": function () {},
    "raw_decrypt": function () {},
    "get_heartbeat": function () {},
    "set_heartbeat": function () {},
    "get_heartbeat_interval": function () {},
    "set_heartbeat_interval": function () {},
    "get_version": function () {},
    "getGcmMessageObject": function () {},
    "getApnsMessageObject": function () {},
    "newPnMessage": function () {},
    "_add_param": function () {},
    "channel_group": function () {},
    "channel_group_list_groups": function () {},
    "channel_group_list_channels": function () {},
    "channel_group_remove_channel": function () {},
    "channel_group_remove_group": function () {},
    "channel_group_add_channel": function () {},
    "channel_group_cloak": function () {},
    "channel_group_list_namespaces": function () {},
    "channel_group_remove_namespace": function () {},
    "history": function () {},
    "replay": function () {},
    "auth": function () {},
    "time": function () {},
    "publish": function () {},
    "unsubscribe": function () {},
    "subscribe": function () {},
    "here_now": function () {},
    "where_now": function () {},
    "state": function () {},
    "grant": function () {},
    "mobile_gw_provision": function () {},
    "audit": function () {},
    "revoke": function () {},
    "set_uuid": function () {},
    "get_uuid": function () {},
    "isArray": function () {},
    "get_subscribed_channels": function () {},
    "presence_heartbeat": function () {},
    "stop_timers": function () {},
    "shutdown": function () {},
    "xdr": function () {},
    "ready": function () {},
    "db": {
        "get": function () {},
        "set": function () {}
    },
    "uuid": function () {},
    "map": function () {},
    "each": function () {},
    "each-channel": function () {},
    "grep": function () {},
    "offline": function () {},
    "supplant": function () {},
    "now": function () {},
    "unique": function () {},
    "updater": function () {},
    "css": function () {},
    "$": function () {},
    "create": function () {},
    "bind": function () {},
    "head": function () {},
    "search": function () {},
    "attr": function () {},
    "events": {
        "list": function () {},
        "unbind": function () {},
        "bind": function () {},
        "fire": function () {}
    },
    "init": function () {},
    "secure": function () {},
    "crypto_obj": {
        "encrypt": function () {},
        "decrypt": function () {}
    },
    "ws": function () {}
}
